from django import forms
from django.forms import widgets
from django.conf import settings

class ImageUploaderWidget(widgets.ClearableFileInput):
    template_name = 'admin/widgets/image_uploader_widget.html'

    def __init__(self, attrs = None):
        super(ImageUploaderWidget, self).__init__(attrs=attrs)

    def get_context(self, name, value, attrs):
        context = super(ImageUploaderWidget, self).get_context(name, value, attrs)
        return context

    @property
    def media(self):
        extra = '' if settings.DEBUG else '.min'
        return forms.Media(
            js=(
                'admin/js/image-uploader-widget%s.js' % extra,
            ),
            css={
                'screen': (
                    'admin/css/image-uploader-widget%s.css' % extra,
                ),
            },
        )



#!/usr/bin/env python
import os
from setuptools import setup, find_packages

f = open(os.path.join(os.path.dirname(__file__), 'README.md'))
readme = f.read()
f.close()

setup(
    name='django-image-uploader-widget',
    version='0.1.7',
    description='Simple Image Uploader Widget for Django-Admin',
    long_description=readme,
    long_description_content_type='text/markdown',
    author='Eduardo Oliveira',
    author_email='eduardo_y05@outlook.com',
    url='https://github.com/inventare/django-image-uploader-widget',
    license='MIT',
    packages=find_packages(
        exclude = ("image_uploader_widget_demo.*", "image_uploader_widget_demo", )
    ),
    include_package_data=True,
    zip_safe=False,
    classifiers=[
        'Development Status :: 5 - Production/Stable',
        'Environment :: Web Environment',
        'Framework :: Django',
        'Intended Audience :: Developers',
        'License :: OSI Approved :: MIT License',
        'Operating System :: OS Independent',
        'Programming Language :: Python',
        'Programming Language :: Python :: 3',
        'Programming Language :: Python :: 3.4',
        'Programming Language :: Python :: 3.5',
        'Programming Language :: Python :: 3.6',
    ],
    keywords='django,admin,widget,image,uploader',
)
